"""
Version information for DIGY
"""

__version__ = "0.1.0"
__author__ = "Tom Sapletta"
__email__ = "info@softreck.dev"
__description__ = "Dynamic Interactive Git deploY - Deploy Python applications from Git repositories"